@@ -25,6 +25,7 @@
  *   Igor Bukanov
  *   Ethan Hugg
  *   Milen Nankov
+ *   Martin Honnen
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -40,20 +41,42 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '9.1.1.6.js';
+gTestfile = '9.1.1.2.js';
 
-START("9.1.1.6 - XML [[HasProperty]]");
+START('9.1.1.2 - XML [[Put]]');
 
-x = <alpha attr1="value1">one<bravo>two<charlie>three</charlie></bravo></alpha>;
-TEST(1, true, "bravo" in x);
-TEST(2, true, 0 in x);
-TEST(3, true, "charlie" in x.bravo);
-TEST(4, true, 0 in x.bravo);
-TEST(5, false, 1 in x);
-TEST(6, false, 1 in x.bravo);
-TEST(7, false, 2 in x);
-TEST(8, false, 2 in x.bravo);
-TEST(9, false, "foobar" in x);
-TEST(10, false, "foobar" in x.bravo);
 
-END();
\ No newline at end of file
+// .
+var x =
+<alpha attr1="value1" attr2="value2">
+    <bravo>
+        one
+        <charlie>two</charlie>
+    </bravo>
+</alpha>;
+
+var correct =
+<charlie>new</charlie>;
+
+x.bravo.charlie = "new"
+TEST(1, correct, x.bravo.charlie)
+x.bravo = <delta>three</delta>
+TEST(2, "three", x.delta.toString())
+
+// .@
+x = <alpha attr1="value1" attr2="value2"><bravo>one<charlie>two</charlie></bravo></alpha>
+x.@attr1 = "newValue"
+TEST_XML(3, "newValue", x.@attr1)
+
+// From Martin
+
+XML.prettyPrinting = false;
+
+var god = <god><name>Kibo</name></god>;
+god.name = <><prename>James</prename><nickname>Kibo</nickname></>;
+
+var expect = '<god><prename>James</prename><nickname>Kibo</nickname></god>';
+actual = god;
+TEST_XML(4, expect, actual);
+
+END();
