@@ -40,34 +40,52 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '13.4.4.28.js';
+gTestfile = '13.4.4.11.js';
 
-START("13.4.4.28 - processingInsructions()");
+START("13.4.4.11 - XML copy()");
 
-TEST(1, true, XML.prototype.hasOwnProperty("processingInstructions"));
+TEST(1, true, XML.prototype.hasOwnProperty("copy"));
 
-XML.ignoreProcessingInstructions = false;
+emps =
+<employees>
+    <employee id="0"><name>Jim</name><age>25</age></employee>
+    <employee id="1"><name>Joe</name><age>20</age></employee>
+</employees>;
 
-// test generic PI
-x = <alpha><?xyz abc="123" michael="wierd"?><?another name="value" ?><bravo>one</bravo></alpha>;
+correct =
+<employee id="0"><name>Jim</name><age>25</age></employee>;
 
-correct = <><?xyz abc="123" michael="wierd"?><?another name="value" ?></>;
+x = emps.employee[0].copy();
 
-TEST(2, correct, x.processingInstructions());
-TEST(3, correct, x.processingInstructions("*"));
+TEST(2, null, x.parent());
+TEST(3, correct, x);
 
-correct = "<?xyz abc=\"123\" michael=\"wierd\"?>";
+// Make sure we're getting a copy, not a ref to orig.
+emps =
+<employees>
+    <employee id="0"><name>Jim</name><age>25</age></employee>
+    <employee id="1"><name>Joe</name><age>20</age></employee>
+</employees>;
 
-TEST_XML(4, correct, x.processingInstructions("xyz"));
+correct =
+<employee id="0"><name>Jim</name><age>25</age></employee>
 
-// test XML-decl
-// Un-comment these tests when we can read in doc starting with PI.
-//x = new XML("<?xml version=\"1.0\" ?><alpha><bravo>one</bravo></alpha>");
+empCopy = emps.employee[0].copy();
 
-//correct = new XMLList(<?xml version="1.0" encoding="utf-8"?>);
+emps.employee[0].name[0] = "Sally";
 
-//test(5, correct, x.processingInstructions());
-//test(6, correct, x.processingInstructions("*"));
-//test(7, correct, x.processingInstructions("xml"));
+TEST(4, correct, empCopy);
+
+// Try copying whole XML twice
+emps =
+<employees>
+    <employee id="0"><name>Jim</name><age>25</age></employee>
+    <employee id="1"><name>Joe</name><age>20</age></employee>
+</employees>;
+
+empCopy = emps.copy();
+x = empCopy.copy();
+
+TEST(5, x, emps);
 
 END();
