@@ -35,33 +35,20 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-385393-10.js';
+var gTestfile = 'regress-358594-04.js';
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 385393;
-var summary = 'Regression test for bug 385393';
-var actual = 'No Crash';
-var expect = 'No Crash';
+var BUGNUMBER = 358594;
+var summary = 'Do not crash on uneval(this).';
+var actual = '';
+var expect = '';
 
-//-----------------------------------------------------------------------------
-test();
-//-----------------------------------------------------------------------------
+printBugNumber(BUGNUMBER);
+printStatus (summary);
 
-function test()
-{
-  enterFunc ('test');
-  printBugNumber(BUGNUMBER);
-  printStatus (summary);
-
-  try
-  {
-    [1 for (x in [])].watch();
-  }
-  catch(ex)
-  {
-  }
-
-  reportCompare(expect, actual, summary);
-
-  exitFunc ('test');
-}
+// don't crash|assert
+f = function () { };
+f.__proto__ = this; 
+this.m setter = f; 
+uneval(this);
+reportCompare(expect, actual, summary);
