@@ -16,10 +16,10 @@
  *
  * The Initial Developer of the Original Code is
  * Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2008
+ * Portions created by the Initial Developer are Copyright (C) 2006
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s):
+ * Contributor(s): Jesse Ruderman
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,10 +35,10 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-452498-077.js';
+var gTestfile = 'regress-352870-02.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 452498;
-var summary = 'TM: upvar2 regression tests';
+var BUGNUMBER = 352870;
+var summary = 'Do not assert for crazy huge gTestcases';
 var actual = '';
 var expect = '';
 
@@ -52,16 +52,18 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
-
-  expect = '1';
-
-// ------- Comment #77 From Brendan Eich
-
-  (function () { const [d] = [1]; [d] = [2]; print(actual = d);})();
-
-  actual = String(actual);
-
-  reportCompare(expect, actual, summary);
+ 
+  expect = /TypeError: \[1, 2, 3, 4\].g (has no properties|is undefined)/;
+  actual = '';
+  try
+  {
+    switch(4) { case [(let (y = [].j(5)) ({}))
+                      for (p in ([1,2,3,4].g).v({},((w).y(z, <x/>))))]: }  }
+  catch(ex)
+  {
+    actual = ex + '';
+  }
+  reportMatch(expect, actual, summary);
 
   exitFunc ('test');
 }
